==> jc-1.4.0.tar.gz: java__5fcup/shift__5faction.h <==
// public class java_cup.shift_action

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class eabe467ea49323be java__5fcup_parse__5faction
// @dep_class 42affc276ac379ae java__5fcup_shift__5faction

// header file dependencies
// @dep_header java__5fcup_parse__5faction

#include "java__5fcup/parse__5faction.h"

#ifndef _JC_java__5fcup_shift__5faction_H_
#define _JC_java__5fcup_shift__5faction_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java__5fcup_lalr__5fstate$object;
struct _jc_java__5fcup_shift__5faction$object;

// Typedefs
typedef struct _jc_java__5fcup_shift__5faction$sub_refs	_jc_java__5fcup_shift__5faction$sub_refs;
typedef struct _jc_java__5fcup_shift__5faction$sub_nonrefs	_jc_java__5fcup_shift__5faction$sub_nonrefs;
typedef struct _jc_java__5fcup_shift__5faction$refs	_jc_java__5fcup_shift__5faction$refs;
typedef struct _jc_java__5fcup_shift__5faction$nonrefs	_jc_java__5fcup_shift__5faction$nonrefs;
typedef struct _jc_java__5fcup_shift__5faction$object	_jc_java__5fcup_shift__5faction$object;

typedef const struct _jc_java__5fcup_shift__5faction$vmethods	_jc_java__5fcup_shift__5faction$vmethods;
typedef const struct _jc_java__5fcup_shift__5faction$vtable	_jc_java__5fcup_shift__5faction$vtable;
typedef const struct _jc_java__5fcup_shift__5faction$vtype	_jc_java__5fcup_shift__5faction$vtype;

// Constructors
extern void _jc_java__5fcup_shift__5faction$method$_init$cb869277bc6a2e6b(_jc_env *, struct _jc_java__5fcup_shift__5faction$object *, struct _jc_java__5fcup_lalr__5fstate$object *);

// Virtual methods
extern jboolean _jc_java__5fcup_shift__5faction$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java__5fcup_shift__5faction$object *, struct _jc_java_lang_Object$object *);
extern jboolean _jc_java__5fcup_shift__5faction$method$equals$e5f4342eb1cbd827(_jc_env *, struct _jc_java__5fcup_shift__5faction$object *, struct _jc_java__5fcup_shift__5faction$object *);
extern jint _jc_java__5fcup_shift__5faction$method$hashCode$53152098849316df(_jc_env *, struct _jc_java__5fcup_shift__5faction$object *);
extern jint _jc_java__5fcup_shift__5faction$method$kind$c10c0c14635410af(_jc_env *, struct _jc_java__5fcup_shift__5faction$object *);
extern struct _jc_java__5fcup_lalr__5fstate$object *_jc_java__5fcup_shift__5faction$method$shift__5fto$d15675d7f7b2bb35(_jc_env *, struct _jc_java__5fcup_shift__5faction$object *);
extern struct _jc_java_lang_String$object *_jc_java__5fcup_shift__5faction$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java__5fcup_shift__5faction$object *);

// Virtual method descriptors
extern _jc_method _jc_java__5fcup_shift__5faction$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java__5fcup_shift__5faction$method_info$equals$e5f4342eb1cbd827;
extern _jc_method _jc_java__5fcup_shift__5faction$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java__5fcup_shift__5faction$method_info$kind$c10c0c14635410af;
extern _jc_method _jc_java__5fcup_shift__5faction$method_info$shift__5fto$d15675d7f7b2bb35;
extern _jc_method _jc_java__5fcup_shift__5faction$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java__5fcup_shift__5faction$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java__5fcup_shift__5faction$object *, struct _jc_java_lang_Object$object *);
	jboolean	(*equals$e5f4342eb1cbd827)(_jc_env *, struct _jc_java__5fcup_shift__5faction$object *, struct _jc_java__5fcup_shift__5faction$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java__5fcup_shift__5faction$object *);
	jint	(*kind$c10c0c14635410af)(_jc_env *, struct _jc_java__5fcup_shift__5faction$object *);
	struct _jc_java__5fcup_lalr__5fstate$object	*(*shift__5fto$d15675d7f7b2bb35)(_jc_env *, struct _jc_java__5fcup_shift__5faction$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java__5fcup_shift__5faction$object *);
};

// Vtable
struct _jc_java__5fcup_shift__5faction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_parse__5faction$vmethods	java__5fcup_parse__5faction;
	_jc_java__5fcup_shift__5faction$vmethods	java__5fcup_shift__5faction;
};

// Vtype
struct _jc_java__5fcup_shift__5faction$vtype {
	_jc_type			type;
	_jc_java__5fcup_shift__5faction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_shift__5faction$sub_refs {
	struct _jc_java__5fcup_lalr__5fstate$object	*__5fshift__5fto;
};

// Reference instance fields (object)
struct _jc_java__5fcup_shift__5faction$refs {
    _jc_java__5fcup_shift__5faction$sub_refs	java__5fcup_shift__5faction;
    _jc_java__5fcup_parse__5faction$sub_refs	java__5fcup_parse__5faction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_shift__5faction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_shift__5faction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_parse__5faction$sub_nonrefs	java__5fcup_parse__5faction;
    _jc_java__5fcup_shift__5faction$sub_nonrefs	java__5fcup_shift__5faction;
};

// Object instance structure
struct _jc_java__5fcup_shift__5faction$object {
	_jc_java__5fcup_shift__5faction$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_shift__5faction$vtype	*vtype;
	_jc_java__5fcup_shift__5faction$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_shift__5faction$vtype _jc_java__5fcup_shift__5faction$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_shift__5faction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_shift__5faction$class_object;

#endif	/* _JC_java__5fcup_shift__5faction_H_ */

==> jc-1.4.6.tar.gz: java__5fcup/shift__5faction.h <==
// public class java_cup.shift_action

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class eabe467ea49323be java__5fcup_parse__5faction
// @dep_class 42affc276ac379ae java__5fcup_shift__5faction

// header file dependencies
// @dep_header java__5fcup_parse__5faction

#include "java__5fcup/parse__5faction.h"

#ifndef _JC_java__5fcup_shift__5faction_H_
#define _JC_java__5fcup_shift__5faction_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java__5fcup_lalr__5fstate$object;
struct _jc_java__5fcup_shift__5faction$object;

// Typedefs
typedef struct _jc_java__5fcup_shift__5faction$sub_refs	_jc_java__5fcup_shift__5faction$sub_refs;
typedef struct _jc_java__5fcup_shift__5faction$sub_nonrefs	_jc_java__5fcup_shift__5faction$sub_nonrefs;
typedef struct _jc_java__5fcup_shift__5faction$refs	_jc_java__5fcup_shift__5faction$refs;
typedef struct _jc_java__5fcup_shift__5faction$nonrefs	_jc_java__5fcup_shift__5faction$nonrefs;
typedef struct _jc_java__5fcup_shift__5faction$object	_jc_java__5fcup_shift__5faction$object;

typedef const struct _jc_java__5fcup_shift__5faction$vmethods	_jc_java__5fcup_shift__5faction$vmethods;
typedef const struct _jc_java__5fcup_shift__5faction$vtable	_jc_java__5fcup_shift__5faction$vtable;
typedef const struct _jc_java__5fcup_shift__5faction$vtype	_jc_java__5fcup_shift__5faction$vtype;

// Constructors
extern void _jc_java__5fcup_shift__5faction$method$_init$cb869277bc6a2e6b(_jc_env *, struct _jc_java__5fcup_shift__5faction$object *, struct _jc_java__5fcup_lalr__5fstate$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java__5fcup_shift__5faction$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java__5fcup_shift__5faction$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java__5fcup_shift__5faction$method$equals$e5f4342eb1cbd827(_jc_env *, struct _jc_java__5fcup_shift__5faction$object *, struct _jc_java__5fcup_shift__5faction$object *) _JC_JCNI_ATTR;
extern jint _jc_java__5fcup_shift__5faction$method$hashCode$53152098849316df(_jc_env *, struct _jc_java__5fcup_shift__5faction$object *) _JC_JCNI_ATTR;
extern jint _jc_java__5fcup_shift__5faction$method$kind$c10c0c14635410af(_jc_env *, struct _jc_java__5fcup_shift__5faction$object *) _JC_JCNI_ATTR;
extern struct _jc_java__5fcup_lalr__5fstate$object *_jc_java__5fcup_shift__5faction$method$shift__5fto$d15675d7f7b2bb35(_jc_env *, struct _jc_java__5fcup_shift__5faction$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java__5fcup_shift__5faction$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java__5fcup_shift__5faction$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java__5fcup_shift__5faction$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java__5fcup_shift__5faction$method_info$equals$e5f4342eb1cbd827;
extern _jc_method _jc_java__5fcup_shift__5faction$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java__5fcup_shift__5faction$method_info$kind$c10c0c14635410af;
extern _jc_method _jc_java__5fcup_shift__5faction$method_info$shift__5fto$d15675d7f7b2bb35;
extern _jc_method _jc_java__5fcup_shift__5faction$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java__5fcup_shift__5faction$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java__5fcup_shift__5faction$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jboolean	(*equals$e5f4342eb1cbd827)(_jc_env *, struct _jc_java__5fcup_shift__5faction$object *, struct _jc_java__5fcup_shift__5faction$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java__5fcup_shift__5faction$object *) _JC_JCNI_ATTR;
	jint	(*kind$c10c0c14635410af)(_jc_env *, struct _jc_java__5fcup_shift__5faction$object *) _JC_JCNI_ATTR;
	struct _jc_java__5fcup_lalr__5fstate$object	*(*shift__5fto$d15675d7f7b2bb35)(_jc_env *, struct _jc_java__5fcup_shift__5faction$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java__5fcup_shift__5faction$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java__5fcup_shift__5faction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_parse__5faction$vmethods	java__5fcup_parse__5faction;
	_jc_java__5fcup_shift__5faction$vmethods	java__5fcup_shift__5faction;
};

// Vtype
struct _jc_java__5fcup_shift__5faction$vtype {
	_jc_type			type;
	_jc_java__5fcup_shift__5faction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_shift__5faction$sub_refs {
	struct _jc_java__5fcup_lalr__5fstate$object	*__5fshift__5fto;
};

// Reference instance fields (object)
struct _jc_java__5fcup_shift__5faction$refs {
    _jc_java__5fcup_shift__5faction$sub_refs	java__5fcup_shift__5faction;
    _jc_java__5fcup_parse__5faction$sub_refs	java__5fcup_parse__5faction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_shift__5faction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_shift__5faction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_parse__5faction$sub_nonrefs	java__5fcup_parse__5faction;
    _jc_java__5fcup_shift__5faction$sub_nonrefs	java__5fcup_shift__5faction;
};

// Object instance structure
struct _jc_java__5fcup_shift__5faction$object {
	_jc_java__5fcup_shift__5faction$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_shift__5faction$vtype	*vtype;
	_jc_java__5fcup_shift__5faction$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_shift__5faction$vtype _jc_java__5fcup_shift__5faction$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_shift__5faction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_shift__5faction$class_object;

#endif	/* _JC_java__5fcup_shift__5faction_H_ */
